@@ -189,7 +189,7 @@ void SetAlwaysOnTop(QWidget *window, bool enable)
 }
 #endif
 
-DrawDock::DrawDock(QWidget *_parent) : QWidget(_parent), eventFilter(BuildEventFilter()), preview(new OBSQTDisplay(this))
+DrawDock::DrawDock(QWidget *_parent) : QFrame(_parent), eventFilter(BuildEventFilter()), preview(new OBSQTDisplay(this))
 {
 	auto ml = new QVBoxLayout(this);
 	ml->setContentsMargins(0, 0, 0, 0);
@@ -321,6 +321,35 @@ DrawDock::DrawDock(QWidget *_parent) : QWidget(_parent), eventFilter(BuildEventF
 			obs_source_update(draw_source, settings);
 			obs_data_release(settings);
 		});
+		a = cursorMenu->addAction(QString::fromUtf8(obs_module_text("CursorHide")));
+		a->setCheckable(true);
+		a->setChecked(obs_data_get_bool(settings, "cursor_hide"));
+		connect(a, &QAction::triggered, [this, a] {
+			if (!draw_source)
+				return;
+			obs_data_t *settings = obs_data_create();
+			obs_data_set_bool(settings, "cursor_hide", a->isChecked());
+			obs_source_update(draw_source, settings);
+			obs_data_release(settings);
+		});
+		auto wa = new QWidgetAction(cursorMenu);
+		auto cursorHide = new QDoubleSpinBox();
+		cursorHide->setSuffix("s");
+		cursorHide->setValue(obs_data_get_double(settings, "cursor_hide_time"));
+		cursorHide->setRange(0.0, 100.0);
+		cursorHide->setEnabled(a->isChecked());
+		wa->setDefaultWidget(cursorHide);
+		cursorMenu->addAction(wa);
+
+		connect(cursorHide, &QDoubleSpinBox::valueChanged, [this, cursorHide] {
+			if (!draw_source)
+				return;
+			obs_data_t *settings = obs_data_create();
+			obs_data_set_double(settings, "cursor_hide_time", cursorHide->value());
+			obs_source_update(draw_source, settings);
+			obs_data_release(settings);
+		});
+
 		cursorMenu->addAction(QString::fromUtf8(obs_module_text("Color")), [this] {
 			if (!draw_source)
 				return;
@@ -357,16 +386,16 @@ DrawDock::DrawDock(QWidget *_parent) : QWidget(_parent), eventFilter(BuildEventF
 		});
 		a = cursorMenu->addAction(QString::fromUtf8(obs_module_text("CursorCustomSize")));
 		a->setCheckable(true);
-		a->setChecked(obs_data_get_bool(settings, "custom_cursor_size"));
+		a->setChecked(obs_data_get_bool(settings, "cursor_custom_size"));
 		connect(a, &QAction::triggered, [this, a] {
 			if (!draw_source)
 				return;
 			obs_data_t *settings = obs_data_create();
-			obs_data_set_bool(settings, "custom_cursor_size", a->isChecked());
+			obs_data_set_bool(settings, "cursor_custom_size", a->isChecked());
 			obs_source_update(draw_source, settings);
 			obs_data_release(settings);
 		});
-		auto wa = new QWidgetAction(cursorMenu);
+		wa = new QWidgetAction(cursorMenu);
 		auto cursorSize = new QDoubleSpinBox();
 		cursorSize->setSuffix("px");
 		cursorSize->setValue(obs_data_get_double(settings, "cursor_size"));
@@ -772,7 +801,13 @@ DrawDock::DrawDock(QWidget *_parent) : QWidget(_parent), eventFilter(BuildEventF
 #endif
 
 	toolbar->addSeparator();
-	toolbar->addAction(QString::fromUtf8(obs_module_text("Clear")), [this] { ClearDraw(); });
+	clearAction = toolbar->addAction(QString::fromUtf8(obs_module_text("Clear")), [this] { ClearDraw(); });
+
+	// Set object names for theming support
+	if (auto *colorButton = toolbar->widgetForAction(colorAction))
+		colorButton->setObjectName(QStringLiteral("drawColorButton"));
+	if (auto *clearButton = toolbar->widgetForAction(clearAction))
+		clearButton->setObjectName(QStringLiteral("drawClearButton"));
 
 	preview->setObjectName(QStringLiteral("preview"));
 	preview->setMinimumSize(QSize(24, 24));
